# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtQml, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtQml`

import PySide6.QtQml
import PySide6.QtCore
import PySide6.QtNetwork

import os
import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class ListProperty(PySide6.QtCore.Property):

    def __init__(self, type: type, /, append: collections.abc.Callable[..., typing.Any] | None = ..., at: collections.abc.Callable[..., typing.Any] | None = ..., clear: collections.abc.Callable[..., typing.Any] | None = ..., count: collections.abc.Callable[..., typing.Any] | None = ...) -> None: ...


class QIntList: ...


class QJSEngine(PySide6.QtCore.QObject):

    uiLanguageChanged        : typing.ClassVar[Signal] = ... # uiLanguageChanged()

    class Extension(enum.Flag):

        TranslationExtension      = 0x1
        ConsoleExtension          = 0x2
        GarbageCollectionExtension = 0x4
        AllExtensions             = 0xffffffff

    class ObjectOwnership(enum.Enum):

        CppOwnership              = 0x0
        JavaScriptOwnership       = 0x1


    @typing.overload
    def __init__(self, parent: PySide6.QtCore.QObject, /, *, uiLanguage: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, uiLanguage: str | None = ...) -> None: ...

    def catchError(self, /) -> PySide6.QtQml.QJSValue: ...
    def collectGarbage(self, /) -> None: ...
    def evaluate(self, program: str, /, fileName: str = ..., lineNumber: int = ...) -> typing.Tuple[PySide6.QtQml.QJSValue, typing.List[str]]: ...
    def globalObject(self, /) -> PySide6.QtQml.QJSValue: ...
    def hasError(self, /) -> bool: ...
    def importModule(self, fileName: str, /) -> PySide6.QtQml.QJSValue: ...
    def installExtensions(self, extensions: PySide6.QtQml.QJSEngine.Extension, /, object: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int = ...) -> None: ...
    def isInterrupted(self, /) -> bool: ...
    def newArray(self, /, length: int | None = ...) -> PySide6.QtQml.QJSValue: ...
    def newErrorObject(self, errorType: PySide6.QtQml.QJSValue.ErrorType, /, message: str = ...) -> PySide6.QtQml.QJSValue: ...
    def newObject(self, /) -> PySide6.QtQml.QJSValue: ...
    def newQMetaObject(self, metaObject: PySide6.QtCore.QMetaObject, /) -> PySide6.QtQml.QJSValue: ...
    def newQObject(self, object: PySide6.QtCore.QObject, /) -> PySide6.QtQml.QJSValue: ...
    def newSymbol(self, name: str, /) -> PySide6.QtQml.QJSValue: ...
    @staticmethod
    def objectOwnership(arg__1: PySide6.QtCore.QObject, /) -> PySide6.QtQml.QJSEngine.ObjectOwnership: ...
    def registerModule(self, moduleName: str, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> bool: ...
    def setInterrupted(self, interrupted: bool, /) -> None: ...
    @staticmethod
    def setObjectOwnership(arg__1: PySide6.QtCore.QObject, arg__2: PySide6.QtQml.QJSEngine.ObjectOwnership, /) -> None: ...
    def setUiLanguage(self, language: str, /) -> None: ...
    @typing.overload
    def throwError(self, errorType: PySide6.QtQml.QJSValue.ErrorType, /, message: str = ...) -> None: ...
    @typing.overload
    def throwError(self, message: str, /) -> None: ...
    @typing.overload
    def throwError(self, error: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...
    def toScriptValue(self, value: typing.Any, /) -> PySide6.QtQml.QJSValue: ...
    def uiLanguage(self, /) -> str: ...


class QJSManagedValue(Shiboken.Object):

    class Type(enum.Enum):

        Undefined                 = 0x0
        Boolean                   = 0x1
        Number                    = 0x2
        String                    = 0x3
        Object                    = 0x4
        Symbol                    = 0x5
        Function                  = 0x6


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, string: str, engine: PySide6.QtQml.QJSEngine, /) -> None: ...
    @typing.overload
    def __init__(self, value: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, engine: PySide6.QtQml.QJSEngine, /) -> None: ...
    @typing.overload
    def __init__(self, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, engine: PySide6.QtQml.QJSEngine, /) -> None: ...
    @typing.overload
    def __init__(self, variant: typing.Any, engine: PySide6.QtQml.QJSEngine, /) -> None: ...

    def call(self, /, arguments: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSValue: ...
    def callAsConstructor(self, /, arguments: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSValue: ...
    def callWithInstance(self, instance: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /, arguments: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSValue: ...
    @typing.overload
    def deleteProperty(self, name: str, /) -> bool: ...
    @typing.overload
    def deleteProperty(self, arrayIndex: int, /) -> bool: ...
    def engine(self, /) -> PySide6.QtQml.QJSEngine: ...
    def equals(self, other: PySide6.QtQml.QJSManagedValue, /) -> bool: ...
    @typing.overload
    def hasOwnProperty(self, name: str, /) -> bool: ...
    @typing.overload
    def hasOwnProperty(self, arrayIndex: int, /) -> bool: ...
    @typing.overload
    def hasProperty(self, name: str, /) -> bool: ...
    @typing.overload
    def hasProperty(self, arrayIndex: int, /) -> bool: ...
    def isArray(self, /) -> bool: ...
    def isBoolean(self, /) -> bool: ...
    def isDate(self, /) -> bool: ...
    def isError(self, /) -> bool: ...
    def isFunction(self, /) -> bool: ...
    def isInteger(self, /) -> bool: ...
    def isJsMetaType(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isNumber(self, /) -> bool: ...
    def isObject(self, /) -> bool: ...
    def isQMetaObject(self, /) -> bool: ...
    def isQObject(self, /) -> bool: ...
    def isRegularExpression(self, /) -> bool: ...
    def isString(self, /) -> bool: ...
    def isSymbol(self, /) -> bool: ...
    def isUndefined(self, /) -> bool: ...
    def isUrl(self, /) -> bool: ...
    def isVariant(self, /) -> bool: ...
    def jsMetaInstantiate(self, /, values: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSManagedValue: ...
    def jsMetaMembers(self, /) -> typing.List[str]: ...
    def jsMetaType(self, /) -> PySide6.QtQml.QJSManagedValue: ...
    @typing.overload
    def property(self, name: str, /) -> PySide6.QtQml.QJSValue: ...
    @typing.overload
    def property(self, arrayIndex: int, /) -> PySide6.QtQml.QJSValue: ...
    def prototype(self, /) -> PySide6.QtQml.QJSManagedValue: ...
    @typing.overload
    def setProperty(self, name: str, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...
    @typing.overload
    def setProperty(self, arrayIndex: int, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...
    def setPrototype(self, prototype: PySide6.QtQml.QJSManagedValue, /) -> None: ...
    def strictlyEquals(self, other: PySide6.QtQml.QJSManagedValue, /) -> bool: ...
    def toBoolean(self, /) -> bool: ...
    def toDateTime(self, /) -> PySide6.QtCore.QDateTime: ...
    def toInteger(self, /) -> int: ...
    def toJSValue(self, /) -> PySide6.QtQml.QJSValue: ...
    def toNumber(self, /) -> float: ...
    def toPrimitive(self, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def toQMetaObject(self, /) -> PySide6.QtCore.QMetaObject: ...
    def toQObject(self, /) -> PySide6.QtCore.QObject: ...
    def toRegularExpression(self, /) -> PySide6.QtCore.QRegularExpression: ...
    def toString(self, /) -> str: ...
    def toUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def toVariant(self, /) -> typing.Any: ...
    def type(self, /) -> PySide6.QtQml.QJSManagedValue.Type: ...


class QJSPrimitiveValue(Shiboken.Object):

    class Type(enum.Enum):

        Undefined                 = 0x0
        Null                      = 0x1
        Boolean                   = 0x2
        Integer                   = 0x3
        Double                    = 0x4
        String                    = 0x5


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, QJSPrimitiveValue: PySide6.QtQml.QJSPrimitiveValue, /) -> None: ...
    @typing.overload
    def __init__(self, string: str, /) -> None: ...
    @typing.overload
    def __init__(self, type: PySide6.QtCore.QMetaType | PySide6.QtCore.QMetaType.Type, /) -> None: ...
    @typing.overload
    def __init__(self, type: PySide6.QtCore.QMetaType | PySide6.QtCore.QMetaType.Type, value: int, /) -> None: ...
    @typing.overload
    def __init__(self, value: bool, /) -> None: ...
    @typing.overload
    def __init__(self, value: int, /) -> None: ...
    @typing.overload
    def __init__(self, value: float, /) -> None: ...
    @typing.overload
    def __init__(self, variant: typing.Any, /) -> None: ...

    def __add__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def __ge__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def __gt__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def __iadd__(self, arg__1: int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...  # type: ignore[misc]
    def __isub__(self, arg__1: int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...  # type: ignore[misc]
    def __le__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def __lt__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def __mod__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def __mul__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def __ne__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def __neg__(self, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def __pos__(self, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def __sub__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def __truediv__(self, rhs: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def constData(self, /) -> int: ...
    def data(self, /) -> int: ...
    def equals(self, other: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def metaType(self, /) -> PySide6.QtCore.QMetaType: ...
    def strictlyEquals(self, other: PySide6.QtQml.QJSPrimitiveValue | str | bool | float | int, /) -> bool: ...
    def toBoolean(self, /) -> bool: ...
    def toDouble(self, /) -> float: ...
    def toInteger(self, /) -> int: ...
    def toString(self, /) -> str: ...
    def toVariant(self, /) -> typing.Any: ...
    def type(self, /) -> PySide6.QtQml.QJSPrimitiveValue.Type: ...


class QJSValue(Shiboken.Object):

    class ErrorType(enum.Enum):

        NoError                   = 0x0
        GenericError              = 0x1
        EvalError                 = 0x2
        RangeError                = 0x3
        ReferenceError            = 0x4
        SyntaxError               = 0x5
        TypeError                 = 0x6
        URIError                  = 0x7

    class ObjectConversionBehavior(enum.Enum):

        ConvertJSObjects          = 0x0
        RetainJSObjects           = 0x1

    class SpecialValue(enum.Enum):

        NullValue                 = 0x0
        UndefinedValue            = 0x1


    @typing.overload
    def __init__(self, other: PySide6.QtQml.QJSValue, /) -> None: ...
    @typing.overload
    def __init__(self, /, value: PySide6.QtQml.QJSValue.SpecialValue = ...) -> None: ...
    @typing.overload
    def __init__(self, value: str, /) -> None: ...
    @typing.overload
    def __init__(self, str: bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def __init__(self, value: bool, /) -> None: ...
    @typing.overload
    def __init__(self, value: int, /) -> None: ...
    @typing.overload
    def __init__(self, value: float, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __lshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def __rshift__(self, arg__1: PySide6.QtCore.QDataStream, /) -> PySide6.QtCore.QDataStream: ...
    def call(self, /, args: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSValue: ...
    def callAsConstructor(self, /, args: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSValue: ...
    def callWithInstance(self, instance: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /, args: collections.abc.Sequence[PySide6.QtQml.QJSValue] = ...) -> PySide6.QtQml.QJSValue: ...
    def deleteProperty(self, name: str, /) -> bool: ...
    def equals(self, other: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> bool: ...
    def errorType(self, /) -> PySide6.QtQml.QJSValue.ErrorType: ...
    def hasOwnProperty(self, name: str, /) -> bool: ...
    def hasProperty(self, name: str, /) -> bool: ...
    def isArray(self, /) -> bool: ...
    def isBool(self, /) -> bool: ...
    def isCallable(self, /) -> bool: ...
    def isDate(self, /) -> bool: ...
    def isError(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isNumber(self, /) -> bool: ...
    def isObject(self, /) -> bool: ...
    def isQMetaObject(self, /) -> bool: ...
    def isQObject(self, /) -> bool: ...
    def isRegExp(self, /) -> bool: ...
    def isString(self, /) -> bool: ...
    def isUndefined(self, /) -> bool: ...
    def isUrl(self, /) -> bool: ...
    def isVariant(self, /) -> bool: ...
    @typing.overload
    def property(self, name: str, /) -> PySide6.QtQml.QJSValue: ...
    @typing.overload
    def property(self, arrayIndex: int, /) -> PySide6.QtQml.QJSValue: ...
    def prototype(self, /) -> PySide6.QtQml.QJSValue: ...
    @typing.overload
    def setProperty(self, name: str, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...
    @typing.overload
    def setProperty(self, arrayIndex: int, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...
    def setPrototype(self, prototype: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...
    def strictlyEquals(self, other: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> bool: ...
    def toBool(self, /) -> bool: ...
    def toDateTime(self, /) -> PySide6.QtCore.QDateTime: ...
    def toInt(self, /) -> int: ...
    def toNumber(self, /) -> float: ...
    def toPrimitive(self, /) -> PySide6.QtQml.QJSPrimitiveValue: ...
    def toQMetaObject(self, /) -> PySide6.QtCore.QMetaObject: ...
    def toQObject(self, /) -> PySide6.QtCore.QObject: ...
    def toString(self, /) -> str: ...
    def toUInt(self, /) -> int: ...
    @typing.overload
    def toVariant(self, /) -> typing.Any: ...
    @typing.overload
    def toVariant(self, behavior: PySide6.QtQml.QJSValue.ObjectConversionBehavior, /) -> typing.Any: ...


class QJSValueIterator(Shiboken.Object):

    def __init__(self, value: PySide6.QtQml.QJSValue | PySide6.QtQml.QJSValue.SpecialValue | bool | str | bytes | bytearray | memoryview | float | int, /) -> None: ...

    def hasNext(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def next(self, /) -> bool: ...
    def value(self, /) -> PySide6.QtQml.QJSValue: ...


class QPyQmlParserStatus(PySide6.QtCore.QObject, PySide6.QtQml.QQmlParserStatus):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


class QPyQmlPropertyValueSource(PySide6.QtCore.QObject, PySide6.QtQml.QQmlPropertyValueSource):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...


class QQmlAbstractUrlInterceptor(Shiboken.Object):

    class DataType(enum.Enum):

        QmlFile                   = 0x0
        JavaScriptFile            = 0x1
        QmldirFile                = 0x2
        UrlString                 = 0x1000


    def __init__(self, /) -> None: ...

    def intercept(self, path: PySide6.QtCore.QUrl | str, type: PySide6.QtQml.QQmlAbstractUrlInterceptor.DataType, /) -> PySide6.QtCore.QUrl: ...


class QQmlApplicationEngine(PySide6.QtQml.QQmlEngine):

    objectCreated            : typing.ClassVar[Signal] = ... # objectCreated(QObject*,QUrl)
    objectCreationFailed     : typing.ClassVar[Signal] = ... # objectCreationFailed(QUrl)

    @typing.overload
    def __init__(self, uri: str, typeName: str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, filePath: str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, url: PySide6.QtCore.QUrl | str, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    @typing.overload
    def load(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    @typing.overload
    def load(self, filePath: str | bytes | os.PathLike[str], /) -> None: ...
    def loadData(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, url: PySide6.QtCore.QUrl | str = ...) -> None: ...
    def loadFromModule(self, uri: str, typeName: str, /) -> None: ...
    def rootObjects(self, /) -> typing.List[PySide6.QtCore.QObject]: ...
    def setExtraFileSelectors(self, extraFileSelectors: collections.abc.Sequence[str], /) -> None: ...
    def setInitialProperties(self, initialProperties: typing.Dict[str, typing.Any], /) -> None: ...


class QQmlComponent(PySide6.QtCore.QObject):

    progressChanged          : typing.ClassVar[Signal] = ... # progressChanged(double)
    statusChanged            : typing.ClassVar[Signal] = ... # statusChanged(QQmlComponent::Status)

    class CompilationMode(enum.Enum):

        PreferSynchronous         = 0x0
        Asynchronous              = 0x1

    class Status(enum.Enum):

        Null                      = 0x0
        Ready                     = 0x1
        Loading                   = 0x2
        Error                     = 0x3


    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlEngine, fileName: str, mode: PySide6.QtQml.QQmlComponent.CompilationMode, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ..., url: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, engine: PySide6.QtQml.QQmlEngine, uri: str, typeName: str, mode: PySide6.QtQml.QQmlComponent.CompilationMode, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ..., url: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, engine: PySide6.QtQml.QQmlEngine, uri: str, typeName: str, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ..., url: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlEngine, fileName: str, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ..., url: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlEngine, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ..., url: PySide6.QtCore.QUrl | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlEngine, url: PySide6.QtCore.QUrl | str, mode: PySide6.QtQml.QQmlComponent.CompilationMode, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlEngine, url: PySide6.QtCore.QUrl | str, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, progress: float | None = ..., status: PySide6.QtQml.QQmlComponent.Status | None = ..., url: PySide6.QtCore.QUrl | None = ...) -> None: ...

    def beginCreate(self, arg__1: PySide6.QtQml.QQmlContext, /) -> PySide6.QtCore.QObject: ...
    def completeCreate(self, /) -> None: ...
    @typing.overload
    def create(self, arg__1: PySide6.QtQml.QQmlIncubator, /, context: PySide6.QtQml.QQmlContext | None = ..., forContext: PySide6.QtQml.QQmlContext | None = ...) -> None: ...
    @typing.overload
    def create(self, /, context: PySide6.QtQml.QQmlContext | None = ...) -> PySide6.QtCore.QObject: ...
    def createObject(self, /, parent: PySide6.QtCore.QObject | None = ..., properties: typing.Dict[str, typing.Any] = ...) -> PySide6.QtCore.QObject: ...
    def createWithInitialProperties(self, initialProperties: typing.Dict[str, typing.Any], /, context: PySide6.QtQml.QQmlContext | None = ...) -> PySide6.QtCore.QObject: ...
    def createWithInitialProperties_withownership(self, initialProperties: typing.Dict[str, typing.Any], /) -> PySide6.QtCore.QObject: ...
    def create_withownership(self, /, context: PySide6.QtQml.QQmlContext | None = ...) -> PySide6.QtCore.QObject: ...
    def creationContext(self, /) -> PySide6.QtQml.QQmlContext: ...
    def engine(self, /) -> PySide6.QtQml.QQmlEngine: ...
    def errorString(self, /) -> str: ...
    def errors(self, /) -> typing.List[PySide6.QtQml.QQmlError]: ...
    def isBound(self, /) -> bool: ...
    def isError(self, /) -> bool: ...
    def isLoading(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isReady(self, /) -> bool: ...
    def loadFromModule(self, uri: str, typeName: str, /, mode: PySide6.QtQml.QQmlComponent.CompilationMode = ...) -> None: ...
    @typing.overload
    def loadUrl(self, url: PySide6.QtCore.QUrl | str, /) -> None: ...
    @typing.overload
    def loadUrl(self, url: PySide6.QtCore.QUrl | str, mode: PySide6.QtQml.QQmlComponent.CompilationMode, /) -> None: ...
    def progress(self, /) -> float: ...
    def setData(self, arg__1: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, baseUrl: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setInitialProperties(self, component: PySide6.QtCore.QObject, properties: typing.Dict[str, typing.Any], /) -> None: ...
    def status(self, /) -> PySide6.QtQml.QQmlComponent.Status: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QQmlContext(PySide6.QtCore.QObject):

    class PropertyPair(Shiboken.Object):

        name                      = ...  # type: str
        value                     = ...  # type: typing.Any

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, PropertyPair: PySide6.QtQml.QQmlContext.PropertyPair, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...


    @typing.overload
    def __init__(self, parent: PySide6.QtQml.QQmlEngine, /, objParent: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: PySide6.QtQml.QQmlContext, /, objParent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def baseUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def childContexts(self, /) -> typing.List[PySide6.QtQml.QQmlContext]: ...
    def contextObject(self, /) -> PySide6.QtCore.QObject: ...
    def contextProperty(self, arg__1: str, /) -> typing.Any: ...
    def engine(self, /) -> PySide6.QtQml.QQmlEngine: ...
    def findObjectRecursively(self, id: str, /) -> PySide6.QtCore.QObject: ...
    def findObjectsRecursively(self, id: str, /) -> typing.List[PySide6.QtCore.QObject]: ...
    def importedScript(self, name: str, /) -> PySide6.QtQml.QJSValue: ...
    def isValid(self, /) -> bool: ...
    def nameForObject(self, arg__1: PySide6.QtCore.QObject, /) -> str: ...
    def objectForName(self, arg__1: str, /) -> PySide6.QtCore.QObject: ...
    def parentContext(self, /) -> PySide6.QtQml.QQmlContext: ...
    def resolvedUrl(self, arg__1: PySide6.QtCore.QUrl | str, /) -> PySide6.QtCore.QUrl: ...
    def setBaseUrl(self, arg__1: PySide6.QtCore.QUrl | str, /) -> None: ...
    def setContextObject(self, arg__1: PySide6.QtCore.QObject, /) -> None: ...
    def setContextProperties(self, properties: collections.abc.Sequence[PySide6.QtQml.QQmlContext.PropertyPair], /) -> None: ...
    @typing.overload
    def setContextProperty(self, arg__1: str, arg__2: PySide6.QtCore.QObject, /) -> None: ...
    @typing.overload
    def setContextProperty(self, arg__1: str, arg__2: typing.Any, /) -> None: ...


class QQmlDebuggingEnabler(Shiboken.Object):

    class StartMode(enum.Enum):

        DoNotWaitForClient        = 0x0
        WaitForClient             = 0x1


    def __init__(self, /, printWarning: bool = ...) -> None: ...

    @staticmethod
    def connectToLocalDebugger(socketFileName: str, /, mode: PySide6.QtQml.QQmlDebuggingEnabler.StartMode = ...) -> bool: ...
    @staticmethod
    def debuggerServices() -> typing.List[str]: ...
    @staticmethod
    def enableDebugging(printWarning: bool, /) -> None: ...
    @staticmethod
    def inspectorServices() -> typing.List[str]: ...
    @staticmethod
    def nativeDebuggerServices() -> typing.List[str]: ...
    @staticmethod
    def profilerServices() -> typing.List[str]: ...
    @staticmethod
    def setServices(services: collections.abc.Sequence[str], /) -> None: ...
    @staticmethod
    def startDebugConnector(pluginName: str, /, configuration: typing.Dict[str, typing.Any] = ...) -> bool: ...
    @staticmethod
    def startTcpDebugServer(port: int, /, mode: PySide6.QtQml.QQmlDebuggingEnabler.StartMode = ..., hostName: str = ...) -> bool: ...


class QQmlEngine(PySide6.QtQml.QJSEngine):

    exit                     : typing.ClassVar[Signal] = ... # exit(int)
    offlineStoragePathChanged: typing.ClassVar[Signal] = ... # offlineStoragePathChanged()
    quit                     : typing.ClassVar[Signal] = ... # quit()
    warnings                 : typing.ClassVar[Signal] = ... # warnings(QList<QQmlError>)

    def __init__(self, /, p: PySide6.QtCore.QObject | None = ..., *, offlineStoragePath: str | None = ...) -> None: ...

    def addImageProvider(self, id: str, arg__2: PySide6.QtQml.QQmlImageProviderBase, /) -> None: ...
    def addImportPath(self, dir: str | bytes | os.PathLike[str], /) -> None: ...
    def addNamedBundle(self, arg__1: str, arg__2: str, /) -> bool: ...
    def addPluginPath(self, dir: str | bytes | os.PathLike[str], /) -> None: ...
    def addUrlInterceptor(self, urlInterceptor: PySide6.QtQml.QQmlAbstractUrlInterceptor, /) -> None: ...
    def baseUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def captureProperty(self, object: PySide6.QtCore.QObject, property: PySide6.QtCore.QMetaProperty, /) -> None: ...
    def clearComponentCache(self, /) -> None: ...
    def clearSingletons(self, /) -> None: ...
    @staticmethod
    def contextForObject(arg__1: PySide6.QtCore.QObject, /) -> PySide6.QtQml.QQmlContext: ...
    def event(self, arg__1: PySide6.QtCore.QEvent, /) -> bool: ...
    def imageProvider(self, id: str, /) -> PySide6.QtQml.QQmlImageProviderBase: ...
    def importPathList(self, /) -> typing.List[str]: ...
    def importPlugin(self, filePath: str, uri: str, errors: collections.abc.Sequence[PySide6.QtQml.QQmlError], /) -> bool: ...
    def incubationController(self, /) -> PySide6.QtQml.QQmlIncubationController: ...
    def interceptUrl(self, url: PySide6.QtCore.QUrl | str, type: PySide6.QtQml.QQmlAbstractUrlInterceptor.DataType, /) -> PySide6.QtCore.QUrl: ...
    def markCurrentFunctionAsTranslationBinding(self, /) -> None: ...
    def networkAccessManager(self, /) -> PySide6.QtNetwork.QNetworkAccessManager: ...
    def networkAccessManagerFactory(self, /) -> PySide6.QtQml.QQmlNetworkAccessManagerFactory: ...
    def offlineStorageDatabaseFilePath(self, databaseName: str, /) -> str: ...
    def offlineStoragePath(self, /) -> str: ...
    def outputWarningsToStandardError(self, /) -> bool: ...
    def pluginPathList(self, /) -> typing.List[str]: ...
    def removeImageProvider(self, id: str, /) -> None: ...
    def removeUrlInterceptor(self, urlInterceptor: PySide6.QtQml.QQmlAbstractUrlInterceptor, /) -> None: ...
    def retranslate(self, /) -> None: ...
    def rootContext(self, /) -> PySide6.QtQml.QQmlContext: ...
    def setBaseUrl(self, arg__1: PySide6.QtCore.QUrl | str, /) -> None: ...
    @staticmethod
    def setContextForObject(arg__1: PySide6.QtCore.QObject, arg__2: PySide6.QtQml.QQmlContext, /) -> None: ...
    def setImportPathList(self, paths: collections.abc.Sequence[str], /) -> None: ...
    def setIncubationController(self, arg__1: PySide6.QtQml.QQmlIncubationController, /) -> None: ...
    def setNetworkAccessManagerFactory(self, arg__1: PySide6.QtQml.QQmlNetworkAccessManagerFactory, /) -> None: ...
    def setOfflineStoragePath(self, dir: str, /) -> None: ...
    def setOutputWarningsToStandardError(self, arg__1: bool, /) -> None: ...
    def setPluginPathList(self, paths: collections.abc.Sequence[str], /) -> None: ...
    def setUrlInterceptor(self, urlInterceptor: PySide6.QtQml.QQmlAbstractUrlInterceptor, /) -> None: ...
    @typing.overload
    def singletonInstance(self, uri: str, typeName: str, /) -> PySide6.QtCore.QObject | PySide6.QtQml.QJSValue | None: ...
    @typing.overload
    def singletonInstance(self, qmlTypeId: int, /) -> PySide6.QtCore.QObject | PySide6.QtQml.QJSValue | None: ...
    def trimComponentCache(self, /) -> None: ...
    def urlInterceptor(self, /) -> PySide6.QtQml.QQmlAbstractUrlInterceptor: ...
    def urlInterceptors(self, /) -> typing.List[PySide6.QtQml.QQmlAbstractUrlInterceptor]: ...


class QQmlError(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlError, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __repr__(self, /) -> str: ...
    def column(self, /) -> int: ...
    def description(self, /) -> str: ...
    def isValid(self, /) -> bool: ...
    def line(self, /) -> int: ...
    def messageType(self, /) -> PySide6.QtCore.QtMsgType: ...
    def object(self, /) -> PySide6.QtCore.QObject: ...
    def setColumn(self, arg__1: int, /) -> None: ...
    def setDescription(self, arg__1: str, /) -> None: ...
    def setLine(self, arg__1: int, /) -> None: ...
    def setMessageType(self, messageType: PySide6.QtCore.QtMsgType, /) -> None: ...
    def setObject(self, arg__1: PySide6.QtCore.QObject, /) -> None: ...
    def setUrl(self, arg__1: PySide6.QtCore.QUrl | str, /) -> None: ...
    def swap(self, other: PySide6.QtQml.QQmlError, /) -> None: ...
    def toString(self, /) -> str: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...


class QQmlExpression(PySide6.QtCore.QObject):

    valueChanged             : typing.ClassVar[Signal] = ... # valueChanged()

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlContext, arg__2: PySide6.QtCore.QObject, arg__3: str, /, arg__4: PySide6.QtCore.QObject | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlScriptString, /, arg__2: PySide6.QtQml.QQmlContext | None = ..., arg__3: PySide6.QtCore.QObject | None = ..., arg__4: PySide6.QtCore.QObject | None = ...) -> None: ...

    def clearError(self, /) -> None: ...
    def columnNumber(self, /) -> int: ...
    def context(self, /) -> PySide6.QtQml.QQmlContext: ...
    def engine(self, /) -> PySide6.QtQml.QQmlEngine: ...
    def error(self, /) -> PySide6.QtQml.QQmlError: ...
    def evaluate(self, /) -> typing.Tuple[typing.Any, bool]: ...
    def expression(self, /) -> str: ...
    def hasError(self, /) -> bool: ...
    def lineNumber(self, /) -> int: ...
    def notifyOnValueChanged(self, /) -> bool: ...
    def scopeObject(self, /) -> PySide6.QtCore.QObject: ...
    def setExpression(self, arg__1: str, /) -> None: ...
    def setNotifyOnValueChanged(self, arg__1: bool, /) -> None: ...
    def setSourceLocation(self, fileName: str, line: int, /, column: int | None = ...) -> None: ...
    def sourceFile(self, /) -> str: ...


class QQmlExtensionInterface(PySide6.QtQml.QQmlTypesExtensionInterface):

    def __init__(self, /) -> None: ...

    def initializeEngine(self, engine: PySide6.QtQml.QQmlEngine, uri: bytes | bytearray | memoryview, /) -> None: ...


class QQmlExtensionPlugin(PySide6.QtCore.QObject, PySide6.QtQml.QQmlExtensionInterface):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def baseUrl(self, /) -> PySide6.QtCore.QUrl: ...
    def initializeEngine(self, engine: PySide6.QtQml.QQmlEngine, uri: bytes | bytearray | memoryview, /) -> None: ...
    def registerTypes(self, uri: bytes | bytearray | memoryview, /) -> None: ...
    def unregisterTypes(self, /) -> None: ...


class QQmlFile(Shiboken.Object):

    class Status(enum.Enum):

        Null                      = 0x0
        Ready                     = 0x1
        Error                     = 0x2
        Loading                   = 0x3


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, engine: PySide6.QtQml.QQmlEngine, url: str, /) -> None: ...
    @typing.overload
    def __init__(self, engine: PySide6.QtQml.QQmlEngine, url: PySide6.QtCore.QUrl | str, /) -> None: ...

    @typing.overload
    def clear(self, /) -> None: ...
    @typing.overload
    def clear(self, object: PySide6.QtCore.QObject, /) -> None: ...
    @typing.overload
    def connectDownloadProgress(self, arg__1: PySide6.QtCore.QObject, arg__2: bytes | bytearray | memoryview, /) -> bool: ...
    @typing.overload
    def connectDownloadProgress(self, arg__1: PySide6.QtCore.QObject, arg__2: int, /) -> bool: ...
    @typing.overload
    def connectFinished(self, arg__1: PySide6.QtCore.QObject, arg__2: bytes | bytearray | memoryview, /) -> bool: ...
    @typing.overload
    def connectFinished(self, arg__1: PySide6.QtCore.QObject, arg__2: int, /) -> bool: ...
    def data(self, /) -> bytes | bytearray | memoryview: ...
    def dataByteArray(self, /) -> PySide6.QtCore.QByteArray: ...
    def error(self, /) -> str: ...
    def isError(self, /) -> bool: ...
    def isLoading(self, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isLocalFile(url: str, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isLocalFile(url: PySide6.QtCore.QUrl | str, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isReady(self, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isSynchronous(url: str, /) -> bool: ...
    @typing.overload
    @staticmethod
    def isSynchronous(url: PySide6.QtCore.QUrl | str, /) -> bool: ...
    @typing.overload
    def load(self, arg__1: PySide6.QtQml.QQmlEngine, arg__2: str, /) -> None: ...
    @typing.overload
    def load(self, arg__1: PySide6.QtQml.QQmlEngine, arg__2: PySide6.QtCore.QUrl | str, /) -> None: ...
    def size(self, /) -> int: ...
    def status(self, /) -> PySide6.QtQml.QQmlFile.Status: ...
    def url(self, /) -> PySide6.QtCore.QUrl: ...
    @typing.overload
    @staticmethod
    def urlToLocalFileOrQrc(arg__1: str, /) -> str: ...
    @typing.overload
    @staticmethod
    def urlToLocalFileOrQrc(arg__1: PySide6.QtCore.QUrl | str, /) -> str: ...


class QQmlFileSelector(PySide6.QtCore.QObject):

    def __init__(self, engine: PySide6.QtQml.QQmlEngine, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    @staticmethod
    def get(arg__1: PySide6.QtQml.QQmlEngine, /) -> PySide6.QtQml.QQmlFileSelector: ...
    def selector(self, /) -> PySide6.QtCore.QFileSelector: ...
    def setExtraSelectors(self, strings: collections.abc.Sequence[str], /) -> None: ...
    def setSelector(self, selector: PySide6.QtCore.QFileSelector, /) -> None: ...


class QQmlImageProviderBase(PySide6.QtCore.QObject):

    class Flag(enum.Flag):

        ForceAsynchronousImageLoading = 0x1

    class ImageType(enum.Enum):

        Invalid                   = 0x0
        Image                     = 0x1
        Pixmap                    = 0x2
        Texture                   = 0x3
        ImageResponse             = 0x4


    def flags(self, /) -> PySide6.QtQml.QQmlImageProviderBase.Flag: ...
    def imageType(self, /) -> PySide6.QtQml.QQmlImageProviderBase.ImageType: ...


class QQmlIncubationController(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def engine(self, /) -> PySide6.QtQml.QQmlEngine: ...
    def incubateFor(self, msecs: int, /) -> None: ...
    def incubateWhile(self, flag: PySide6.QtQml.VolatileBool, /, msecs: int | None = ...) -> None: ...
    def incubatingObjectCount(self, /) -> int: ...
    def incubatingObjectCountChanged(self, arg__1: int, /) -> None: ...


class QQmlIncubator(Shiboken.Object):

    class IncubationMode(enum.Enum):

        Asynchronous              = 0x0
        AsynchronousIfNested      = 0x1
        Synchronous               = 0x2

    class Status(enum.Enum):

        Null                      = 0x0
        Ready                     = 0x1
        Loading                   = 0x2
        Error                     = 0x3


    def __init__(self, /, arg__1: PySide6.QtQml.QQmlIncubator.IncubationMode = ...) -> None: ...

    def clear(self, /) -> None: ...
    def errors(self, /) -> typing.List[PySide6.QtQml.QQmlError]: ...
    def forceCompletion(self, /) -> None: ...
    def incubationMode(self, /) -> PySide6.QtQml.QQmlIncubator.IncubationMode: ...
    def isError(self, /) -> bool: ...
    def isLoading(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isReady(self, /) -> bool: ...
    def object(self, /) -> PySide6.QtCore.QObject: ...
    def setInitialProperties(self, initialProperties: typing.Dict[str, typing.Any], /) -> None: ...
    def setInitialState(self, arg__1: PySide6.QtCore.QObject, /) -> None: ...
    def status(self, /) -> PySide6.QtQml.QQmlIncubator.Status: ...
    def statusChanged(self, arg__1: PySide6.QtQml.QQmlIncubator.Status, /) -> None: ...


class QQmlListReference(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, o: PySide6.QtCore.QObject, property: bytes | bytearray | memoryview, /) -> None: ...
    @typing.overload
    def __init__(self, o: PySide6.QtCore.QObject, property: bytes | bytearray | memoryview, engine: PySide6.QtQml.QQmlEngine, /) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlListReference, /) -> None: ...
    @typing.overload
    def __init__(self, variant: typing.Any, /) -> None: ...
    @typing.overload
    def __init__(self, variant: typing.Any, engine: PySide6.QtQml.QQmlEngine, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtQml.QQmlListReference, /) -> bool: ...
    def append(self, arg__1: PySide6.QtCore.QObject, /) -> bool: ...
    def at(self, arg__1: int, /) -> PySide6.QtCore.QObject: ...
    def canAppend(self, /) -> bool: ...
    def canAt(self, /) -> bool: ...
    def canClear(self, /) -> bool: ...
    def canCount(self, /) -> bool: ...
    def canRemoveLast(self, /) -> bool: ...
    def canReplace(self, /) -> bool: ...
    def clear(self, /) -> bool: ...
    def count(self, /) -> int: ...
    def isManipulable(self, /) -> bool: ...
    def isReadable(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def listElementType(self, /) -> PySide6.QtCore.QMetaObject: ...
    def object(self, /) -> PySide6.QtCore.QObject: ...
    def removeLast(self, /) -> bool: ...
    def replace(self, arg__1: int, arg__2: PySide6.QtCore.QObject, /) -> bool: ...
    def size(self, /) -> int: ...


class QQmlModuleImportSpecialVersions(enum.Flag):

    QQmlModuleImportAuto      = -2
    QQmlModuleImportLatest    = -1
    QQmlModuleImportModuleAny = -1


class QQmlNetworkAccessManagerFactory(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def create(self, parent: PySide6.QtCore.QObject, /) -> PySide6.QtNetwork.QNetworkAccessManager: ...


class QQmlParserStatus(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def classBegin(self, /) -> None: ...
    def componentComplete(self, /) -> None: ...


class QQmlProperty(Shiboken.Object):

    class PropertyTypeCategory(enum.Enum):

        InvalidCategory           = 0x0
        List                      = 0x1
        Object                    = 0x2
        Normal                    = 0x3

    class Type(enum.Enum):

        Invalid                   = 0x0
        Property                  = 0x1
        SignalProperty            = 0x2


    @typing.overload
    def __init__(self, arg__1: PySide6.QtCore.QObject, arg__2: PySide6.QtQml.QQmlEngine, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtCore.QObject, arg__2: PySide6.QtQml.QQmlContext, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: PySide6.QtQml.QQmlEngine, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: PySide6.QtQml.QQmlContext, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtCore.QObject, arg__2: str, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtCore.QObject, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlProperty, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, object: PySide6.QtCore.QObject | None = ..., name: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, arg__1: PySide6.QtQml.QQmlProperty | PySide6.QtCore.QObject, /) -> bool: ...
    def __hash__(self, /) -> int: ...
    @typing.overload
    def connectNotifySignal(self, dest: PySide6.QtCore.QObject, slot: bytes | bytearray | memoryview, /) -> bool: ...
    @typing.overload
    def connectNotifySignal(self, dest: PySide6.QtCore.QObject, method: int, /) -> bool: ...
    def hasNotifySignal(self, /) -> bool: ...
    def index(self, /) -> int: ...
    def isBindable(self, /) -> bool: ...
    def isDesignable(self, /) -> bool: ...
    def isProperty(self, /) -> bool: ...
    def isResettable(self, /) -> bool: ...
    def isSignalProperty(self, /) -> bool: ...
    def isValid(self, /) -> bool: ...
    def isWritable(self, /) -> bool: ...
    def method(self, /) -> PySide6.QtCore.QMetaMethod: ...
    def name(self, /) -> str: ...
    def needsNotifySignal(self, /) -> bool: ...
    def object(self, /) -> PySide6.QtCore.QObject: ...
    def property(self, /) -> PySide6.QtCore.QMetaProperty: ...
    def propertyMetaType(self, /) -> PySide6.QtCore.QMetaType: ...
    def propertyType(self, /) -> int: ...
    def propertyTypeCategory(self, /) -> PySide6.QtQml.QQmlProperty.PropertyTypeCategory: ...
    def propertyTypeName(self, /) -> bytes | bytearray | memoryview: ...
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    @staticmethod
    def read(arg__1: PySide6.QtCore.QObject, arg__2: str, /) -> typing.Any: ...  # type: ignore[misc, overload-cannot-match]
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    @staticmethod
    def read(arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: PySide6.QtQml.QQmlEngine, /) -> typing.Any: ...  # type: ignore[misc, overload-cannot-match]
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    @staticmethod
    def read(arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: PySide6.QtQml.QQmlContext, /) -> typing.Any: ...  # type: ignore[misc, overload-cannot-match]
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    def read(self, /) -> typing.Any: ...  # type: ignore[misc, overload-cannot-match]
    def reset(self, /) -> bool: ...
    def swap(self, other: PySide6.QtQml.QQmlProperty | PySide6.QtCore.QObject, /) -> None: ...
    def type(self, /) -> PySide6.QtQml.QQmlProperty.Type: ...
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    @staticmethod
    def write(arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: typing.Any, /) -> bool: ...  # type: ignore[misc, overload-cannot-match]
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    @staticmethod
    def write(arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: typing.Any, arg__4: PySide6.QtQml.QQmlEngine, /) -> bool: ...  # type: ignore[misc, overload-cannot-match]
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    @staticmethod
    def write(arg__1: PySide6.QtCore.QObject, arg__2: str, arg__3: typing.Any, arg__4: PySide6.QtQml.QQmlContext, /) -> bool: ...  # type: ignore[misc, overload-cannot-match]
    @typing.overload  # type: ignore[misc, overload-cannot-match]
    def write(self, arg__1: typing.Any, /) -> bool: ...  # type: ignore[misc, overload-cannot-match]


class QQmlPropertyMap(PySide6.QtCore.QObject):

    valueChanged             : typing.ClassVar[Signal] = ... # valueChanged(QString,QVariant)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def clear(self, key: str, /) -> None: ...
    def contains(self, key: str, /) -> bool: ...
    def count(self, /) -> int: ...
    @staticmethod
    def create(parent: PySide6.QtCore.QObject | None = ...) -> PySide6.QtQml.QQmlPropertyMap: ...
    def freeze(self, /) -> None: ...
    @typing.overload
    def insert(self, key: str, value: typing.Any, /) -> None: ...
    @typing.overload
    def insert(self, values: typing.Dict[str, typing.Any], /) -> None: ...
    def isEmpty(self, /) -> bool: ...
    def keys(self, /) -> typing.List[str]: ...
    def size(self, /) -> int: ...
    def updateValue(self, key: str, input: typing.Any, /) -> typing.Any: ...
    def value(self, key: str, /) -> typing.Any: ...


class QQmlPropertyValueSource(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def setTarget(self, arg__1: PySide6.QtQml.QQmlProperty | PySide6.QtCore.QObject, /) -> None: ...


class QQmlScriptString(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, arg__1: PySide6.QtQml.QQmlScriptString, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, arg__1: PySide6.QtQml.QQmlScriptString, /) -> bool: ...
    def __ne__(self, arg__1: PySide6.QtQml.QQmlScriptString, /) -> bool: ...
    def booleanLiteral(self, /) -> typing.Tuple[bool, bool]: ...
    def isEmpty(self, /) -> bool: ...
    def isNullLiteral(self, /) -> bool: ...
    def isUndefinedLiteral(self, /) -> bool: ...
    def numberLiteral(self, /) -> typing.Tuple[float, bool]: ...
    def stringLiteral(self, /) -> str: ...


class QQmlTypesExtensionInterface(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def registerTypes(self, uri: bytes | bytearray | memoryview, /) -> None: ...


class QmlAttached:

    def __init__(self, type: type, /) -> None: ...


class QmlExtended:

    def __init__(self, type: type, /) -> None: ...


class QmlForeign:

    def __init__(self, type: type, /) -> None: ...


class QmlNamedElement:

    def __init__(self, reason: str, /) -> None: ...


class QmlUncreatable:

    def __init__(self, reason: str, /) -> None: ...


class VolatileBool:
    def __repr__(self, /) -> str: ...
    def get(self, /) -> bool: ...
    def set(self, a: object, /) -> None: ...


def QmlAnonymous(arg__1: object, /) -> object: ...
def QmlElement(arg__1: object, /) -> object: ...
def QmlSingleton(arg__1: object, /) -> object: ...
def __dir__(self, /) -> collections.abc.Iterable[str]: ...
def qjsEngine(arg__1: PySide6.QtCore.QObject, /) -> PySide6.QtQml.QJSEngine | None: ...
def qmlAttachedPropertiesObject(type_obj: type, arg__2: PySide6.QtCore.QObject, /, arg__3: bool = ...) -> PySide6.QtCore.QObject: ...
def qmlClearTypeRegistrations() -> None: ...
def qmlContext(arg__1: PySide6.QtCore.QObject, /) -> PySide6.QtQml.QQmlContext | None: ...
def qmlEngine(arg__1: PySide6.QtCore.QObject, /) -> PySide6.QtQml.QQmlEngine | None: ...
def qmlProtectModule(uri: bytes | bytearray | memoryview, majVersion: int, /) -> bool: ...
def qmlRegisterModule(uri: bytes | bytearray | memoryview, versionMajor: int, versionMinor: int, /) -> None: ...
def qmlRegisterSingletonInstance(type_obj: type, uri: str, version_major: int, version_minor: int, qml_name: bytes | bytearray | memoryview, callback: object, /) -> int: ...
@typing.overload
def qmlRegisterSingletonType(uri: str, version_major: int, version_minor: int, qml_name: bytes | bytearray | memoryview, callback: object, /) -> int: ...
@typing.overload
def qmlRegisterSingletonType(type_obj: type, uri: str, version_major: int, version_minor: int, qml_name: bytes | bytearray | memoryview, /) -> int: ...
@typing.overload
def qmlRegisterSingletonType(type_obj: type, uri: str, version_major: int, version_minor: int, qml_name: bytes | bytearray | memoryview, callback: object, /) -> int: ...
@typing.overload
def qmlRegisterSingletonType(url: PySide6.QtCore.QUrl | str, uri: bytes | bytearray | memoryview, versionMajor: int, versionMinor: int, qmlName: bytes | bytearray | memoryview, /) -> int: ...
@typing.overload
def qmlRegisterType(type_obj: type, uri: str, version_major: int, version_minor: int, qml_name: bytes | bytearray | memoryview, /) -> int: ...
@typing.overload
def qmlRegisterType(url: PySide6.QtCore.QUrl | str, uri: bytes | bytearray | memoryview, versionMajor: int, versionMinor: int, qmlName: bytes | bytearray | memoryview, /) -> int: ...
def qmlRegisterUncreatableMetaObject(staticMetaObject: PySide6.QtCore.QMetaObject, uri: bytes | bytearray | memoryview, versionMajor: int, versionMinor: int, qmlName: bytes | bytearray | memoryview, reason: str, /) -> int: ...
def qmlRegisterUncreatableType(type_obj: type, uri: str, version_major: int, version_minor: int, qml_name: bytes | bytearray | memoryview, message: bytes | bytearray | memoryview, /) -> int: ...
def qmlTypeId(uri: bytes | bytearray | memoryview, versionMajor: int, versionMinor: int, qmlName: bytes | bytearray | memoryview, /) -> int: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtWebChannel, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtWebChannel`

import PySide6.QtWebChannel
import PySide6.QtCore

import typing
import collections.abc
from PySide6.QtCore import Signal


class QIntList: ...


class QWebChannel(PySide6.QtCore.QObject):

    blockUpdatesChanged      : typing.ClassVar[Signal] = ... # blockUpdatesChanged(bool)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, blockUpdates: bool | None = ..., propertyUpdateInterval: int | None = ...) -> None: ...

    def blockUpdates(self, /) -> bool: ...
    def connectTo(self, transport: PySide6.QtWebChannel.QWebChannelAbstractTransport, /) -> None: ...
    def deregisterObject(self, object: PySide6.QtCore.QObject, /) -> None: ...
    def disconnectFrom(self, transport: PySide6.QtWebChannel.QWebChannelAbstractTransport, /) -> None: ...
    def propertyUpdateInterval(self, /) -> int: ...
    def registerObject(self, id: str, object: PySide6.QtCore.QObject, /) -> None: ...
    def registerObjects(self, objects: typing.Dict[str, PySide6.QtCore.QObject], /) -> None: ...
    def registeredObjects(self, /) -> typing.Dict[str, PySide6.QtCore.QObject]: ...
    def setBlockUpdates(self, block: bool, /) -> None: ...
    def setPropertyUpdateInterval(self, ms: int, /) -> None: ...


class QWebChannelAbstractTransport(PySide6.QtCore.QObject):

    messageReceived          : typing.ClassVar[Signal] = ... # messageReceived(QJsonObject,QWebChannelAbstractTransport*)

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def sendMessage(self, message: typing.Dict[str, PySide6.QtCore.QJsonValue], /) -> None: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtScxml, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtScxml`

import PySide6.QtScxml
import PySide6.QtCore

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


class QIntList: ...


class QScxmlCompiler(Shiboken.Object):

    class Loader(Shiboken.Object):

        def __init__(self, /) -> None: ...

        def load(self, name: str, baseDir: str, /) -> typing.Tuple[PySide6.QtCore.QByteArray, typing.List[str]]: ...


    def __init__(self, xmlReader: PySide6.QtCore.QXmlStreamReader, /) -> None: ...

    def compile(self, /) -> PySide6.QtScxml.QScxmlStateMachine: ...
    def errors(self, /) -> typing.List[PySide6.QtScxml.QScxmlError]: ...
    def fileName(self, /) -> str: ...
    def loader(self, /) -> PySide6.QtScxml.QScxmlCompiler.Loader: ...
    def setFileName(self, fileName: str, /) -> None: ...
    def setLoader(self, newLoader: PySide6.QtScxml.QScxmlCompiler.Loader, /) -> None: ...


class QScxmlCppDataModel(PySide6.QtScxml.QScxmlDataModel):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def evaluateAssignment(self, id: int, /) -> bool: ...
    def evaluateForeach(self, id: int, body: PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody, /) -> bool: ...
    def evaluateInitialization(self, id: int, /) -> bool: ...
    def hasScxmlProperty(self, name: str, /) -> bool: ...
    def inState(self, stateName: str, /) -> bool: ...
    def scxmlEvent(self, /) -> PySide6.QtScxml.QScxmlEvent: ...
    def scxmlProperty(self, name: str, /) -> typing.Any: ...
    def setScxmlEvent(self, scxmlEvent: PySide6.QtScxml.QScxmlEvent, /) -> None: ...
    def setScxmlProperty(self, name: str, value: typing.Any, context: str, /) -> bool: ...
    def setup(self, initialDataValues: typing.Dict[str, typing.Any], /) -> bool: ...


class QScxmlDataModel(PySide6.QtCore.QObject):

    stateMachineChanged      : typing.ClassVar[Signal] = ... # stateMachineChanged(QScxmlStateMachine*)

    class ForeachLoopBody(Shiboken.Object):

        def __init__(self, /) -> None: ...

        def run(self, /) -> bool: ...


    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ..., *, stateMachine: PySide6.QtScxml.QScxmlStateMachine | None = ...) -> None: ...

    @staticmethod
    def createScxmlDataModel(pluginKey: str, /) -> PySide6.QtScxml.QScxmlDataModel: ...
    def evaluateAssignment(self, id: int, /) -> bool: ...
    def evaluateForeach(self, id: int, body: PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody, /) -> bool: ...
    def evaluateInitialization(self, id: int, /) -> bool: ...
    def evaluateToBool(self, id: int, /) -> bool: ...
    def evaluateToString(self, id: int, /) -> str: ...
    def evaluateToVariant(self, id: int, /) -> typing.Any: ...
    def evaluateToVoid(self, id: int, /) -> bool: ...
    def hasScxmlProperty(self, name: str, /) -> bool: ...
    def scxmlProperty(self, name: str, /) -> typing.Any: ...
    def setScxmlEvent(self, event: PySide6.QtScxml.QScxmlEvent, /) -> None: ...
    def setScxmlProperty(self, name: str, value: typing.Any, context: str, /) -> bool: ...
    def setStateMachine(self, stateMachine: PySide6.QtScxml.QScxmlStateMachine, /) -> None: ...
    def setup(self, initialDataValues: typing.Dict[str, typing.Any], /) -> bool: ...
    def stateMachine(self, /) -> PySide6.QtScxml.QScxmlStateMachine: ...


class QScxmlDynamicScxmlServiceFactory(PySide6.QtScxml.QScxmlInvokableServiceFactory):

    def __init__(self, invokeInfo: PySide6.QtScxml.QScxmlExecutableContent.InvokeInfo, names: collections.abc.Sequence[int], parameters: collections.abc.Sequence[PySide6.QtScxml.QScxmlExecutableContent.ParameterInfo], /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def invoke(self, parentStateMachine: PySide6.QtScxml.QScxmlStateMachine, /) -> PySide6.QtScxml.QScxmlInvokableService: ...


class QScxmlError(Shiboken.Object):

    @typing.overload
    def __init__(self, arg__1: PySide6.QtScxml.QScxmlError, /, *, valid: bool | None = ..., fileName: str | None = ..., line: int | None = ..., column: int | None = ..., description: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, fileName: str, line: int, column: int, description: str, /, *, valid: bool | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, valid: bool | None = ..., fileName: str | None = ..., line: int | None = ..., column: int | None = ..., description: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def column(self, /) -> int: ...
    def description(self, /) -> str: ...
    def fileName(self, /) -> str: ...
    def isValid(self, /) -> bool: ...
    def line(self, /) -> int: ...
    def toString(self, /) -> str: ...


class QScxmlEvent(Shiboken.Object):

    class EventType(enum.Enum):

        PlatformEvent             = 0x0
        InternalEvent             = 0x1
        ExternalEvent             = 0x2


    @typing.overload
    def __init__(self, other: PySide6.QtScxml.QScxmlEvent, /, *, name: str | None = ..., eventType: PySide6.QtScxml.QScxmlEvent.EventType | None = ..., scxmlType: str | None = ..., sendId: str | None = ..., origin: str | None = ..., originType: str | None = ..., invokeId: str | None = ..., delay: int | None = ..., data: typing.Any | None = ..., errorEvent: bool | None = ..., errorMessage: str | None = ...) -> None: ...
    @typing.overload
    def __init__(self, /, *, name: str | None = ..., eventType: PySide6.QtScxml.QScxmlEvent.EventType | None = ..., scxmlType: str | None = ..., sendId: str | None = ..., origin: str | None = ..., originType: str | None = ..., invokeId: str | None = ..., delay: int | None = ..., data: typing.Any | None = ..., errorEvent: bool | None = ..., errorMessage: str | None = ...) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def clear(self, /) -> None: ...
    def data(self, /) -> typing.Any: ...
    def delay(self, /) -> int: ...
    def errorMessage(self, /) -> str: ...
    def eventType(self, /) -> PySide6.QtScxml.QScxmlEvent.EventType: ...
    def invokeId(self, /) -> str: ...
    def isErrorEvent(self, /) -> bool: ...
    def name(self, /) -> str: ...
    def origin(self, /) -> str: ...
    def originType(self, /) -> str: ...
    def scxmlType(self, /) -> str: ...
    def sendId(self, /) -> str: ...
    def setData(self, data: typing.Any, /) -> None: ...
    def setDelay(self, delayInMiliSecs: int, /) -> None: ...
    def setErrorMessage(self, message: str, /) -> None: ...
    def setEventType(self, type: PySide6.QtScxml.QScxmlEvent.EventType, /) -> None: ...
    def setInvokeId(self, invokeId: str, /) -> None: ...
    def setName(self, name: str, /) -> None: ...
    def setOrigin(self, origin: str, /) -> None: ...
    def setOriginType(self, originType: str, /) -> None: ...
    def setSendId(self, sendId: str, /) -> None: ...


class QScxmlExecutableContent(Shiboken.Object):

    class AssignmentInfo(Shiboken.Object):

        context                   = ...  # type: int
        dest                      = ...  # type: int
        expr                      = ...  # type: int

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, AssignmentInfo: PySide6.QtScxml.QScxmlExecutableContent.AssignmentInfo, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...

    class EvaluatorInfo(Shiboken.Object):

        context                   = ...  # type: int
        expr                      = ...  # type: int

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, EvaluatorInfo: PySide6.QtScxml.QScxmlExecutableContent.EvaluatorInfo, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...

    class ForeachInfo(Shiboken.Object):

        array                     = ...  # type: int
        context                   = ...  # type: int
        index                     = ...  # type: int
        item                      = ...  # type: int

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, ForeachInfo: PySide6.QtScxml.QScxmlExecutableContent.ForeachInfo, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...

    class InvokeInfo(Shiboken.Object):

        autoforward               = ...  # type: bool
        context                   = ...  # type: int
        expr                      = ...  # type: int
        finalize                  = ...  # type: int
        id                        = ...  # type: int
        location                  = ...  # type: int
        prefix                    = ...  # type: int

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, InvokeInfo: PySide6.QtScxml.QScxmlExecutableContent.InvokeInfo, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...

    class ParameterInfo(Shiboken.Object):

        expr                      = ...  # type: int
        location                  = ...  # type: int
        name                      = ...  # type: int

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, ParameterInfo: PySide6.QtScxml.QScxmlExecutableContent.ParameterInfo, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...


class QScxmlInvokableService(PySide6.QtCore.QObject):

    def __init__(self, parentStateMachine: PySide6.QtScxml.QScxmlStateMachine, parent: PySide6.QtScxml.QScxmlInvokableServiceFactory, /, *, id: str | None = ..., name: str | None = ...) -> None: ...

    def id(self, /) -> str: ...
    def name(self, /) -> str: ...
    def parentStateMachine(self, /) -> PySide6.QtScxml.QScxmlStateMachine: ...
    def postEvent(self, event: PySide6.QtScxml.QScxmlEvent, /) -> None: ...
    def start(self, /) -> bool: ...


class QScxmlInvokableServiceFactory(PySide6.QtCore.QObject):

    def __init__(self, invokeInfo: PySide6.QtScxml.QScxmlExecutableContent.InvokeInfo, names: collections.abc.Sequence[int], parameters: collections.abc.Sequence[PySide6.QtScxml.QScxmlExecutableContent.ParameterInfo], /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def invoke(self, parentStateMachine: PySide6.QtScxml.QScxmlStateMachine, /) -> PySide6.QtScxml.QScxmlInvokableService: ...
    def invokeInfo(self, /) -> PySide6.QtScxml.QScxmlExecutableContent.InvokeInfo: ...
    def names(self, /) -> typing.List[int]: ...
    def parameters(self, /) -> typing.List[PySide6.QtScxml.QScxmlExecutableContent.ParameterInfo]: ...


class QScxmlNullDataModel(PySide6.QtScxml.QScxmlDataModel):

    def __init__(self, /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def evaluateAssignment(self, id: int, /) -> bool: ...
    def evaluateForeach(self, id: int, body: PySide6.QtScxml.QScxmlDataModel.ForeachLoopBody, /) -> bool: ...
    def evaluateInitialization(self, id: int, /) -> bool: ...
    def evaluateToBool(self, id: int, /) -> bool: ...
    def evaluateToString(self, id: int, /) -> str: ...
    def evaluateToVariant(self, id: int, /) -> typing.Any: ...
    def evaluateToVoid(self, id: int, /) -> bool: ...
    def hasScxmlProperty(self, name: str, /) -> bool: ...
    def scxmlProperty(self, name: str, /) -> typing.Any: ...
    def setScxmlEvent(self, event: PySide6.QtScxml.QScxmlEvent, /) -> None: ...
    def setScxmlProperty(self, name: str, value: typing.Any, context: str, /) -> bool: ...
    def setup(self, initialDataValues: typing.Dict[str, typing.Any], /) -> bool: ...


class QScxmlStateMachine(PySide6.QtCore.QObject):

    dataModelChanged         : typing.ClassVar[Signal] = ... # dataModelChanged(QScxmlDataModel*)
    finished                 : typing.ClassVar[Signal] = ... # finished()
    initialValuesChanged     : typing.ClassVar[Signal] = ... # initialValuesChanged(QVariantMap)
    initializedChanged       : typing.ClassVar[Signal] = ... # initializedChanged(bool)
    invokedServicesChanged   : typing.ClassVar[Signal] = ... # invokedServicesChanged(QList<QScxmlInvokableService*>)
    loaderChanged            : typing.ClassVar[Signal] = ... # loaderChanged(QScxmlCompiler::Loader*)
    log                      : typing.ClassVar[Signal] = ... # log(QString,QString)
    reachedStableState       : typing.ClassVar[Signal] = ... # reachedStableState()
    runningChanged           : typing.ClassVar[Signal] = ... # runningChanged(bool)
    tableDataChanged         : typing.ClassVar[Signal] = ... # tableDataChanged(QScxmlTableData*)

    def __init__(self, metaObject: PySide6.QtCore.QMetaObject, /, parent: PySide6.QtCore.QObject | None = ..., *, running: bool | None = ..., initialized: bool | None = ..., dataModel: PySide6.QtScxml.QScxmlDataModel | None = ..., initialValues: typing.Dict[str, typing.Any] | None = ..., invokedServices: collections.abc.Sequence[PySide6.QtScxml.QScxmlInvokableService] | None = ..., sessionId: str | None = ..., name: str | None = ..., invoked: bool | None = ..., parseErrors: collections.abc.Sequence[PySide6.QtScxml.QScxmlError] | None = ..., loader: PySide6.QtScxml.QScxmlCompiler.Loader | None = ..., tableData: PySide6.QtScxml.QScxmlTableData | None = ...) -> None: ...

    def activeStateNames(self, /, compress: bool = ...) -> typing.List[str]: ...
    def cancelDelayedEvent(self, sendId: str, /) -> None: ...
    def connectToEvent(self, scxmlEventSpec: str, receiver: PySide6.QtCore.QObject, method: bytes | bytearray | memoryview, /, type: PySide6.QtCore.Qt.ConnectionType = ...) -> PySide6.QtCore.QMetaObject.Connection: ...
    def connectToState(self, scxmlStateName: str, receiver: PySide6.QtCore.QObject, method: bytes | bytearray | memoryview, /, type: PySide6.QtCore.Qt.ConnectionType = ...) -> PySide6.QtCore.QMetaObject.Connection: ...
    def dataModel(self, /) -> PySide6.QtScxml.QScxmlDataModel: ...
    @staticmethod
    def fromData(data: PySide6.QtCore.QIODevice, /, fileName: str = ...) -> PySide6.QtScxml.QScxmlStateMachine: ...
    @staticmethod
    def fromFile(fileName: str, /) -> PySide6.QtScxml.QScxmlStateMachine: ...
    def init(self, /) -> bool: ...
    def initialValues(self, /) -> typing.Dict[str, typing.Any]: ...
    def invokedServices(self, /) -> typing.List[PySide6.QtScxml.QScxmlInvokableService]: ...
    @typing.overload
    def isActive(self, scxmlStateName: str, /) -> bool: ...
    @typing.overload
    def isActive(self, stateIndex: int, /) -> bool: ...
    def isDispatchableTarget(self, target: str, /) -> bool: ...
    def isInitialized(self, /) -> bool: ...
    def isInvoked(self, /) -> bool: ...
    def isRunning(self, /) -> bool: ...
    def loader(self, /) -> PySide6.QtScxml.QScxmlCompiler.Loader: ...
    def name(self, /) -> str: ...
    def parseErrors(self, /) -> typing.List[PySide6.QtScxml.QScxmlError]: ...
    def sessionId(self, /) -> str: ...
    def setDataModel(self, model: PySide6.QtScxml.QScxmlDataModel, /) -> None: ...
    def setInitialValues(self, initialValues: typing.Dict[str, typing.Any], /) -> None: ...
    def setLoader(self, loader: PySide6.QtScxml.QScxmlCompiler.Loader, /) -> None: ...
    def setRunning(self, running: bool, /) -> None: ...
    def setTableData(self, tableData: PySide6.QtScxml.QScxmlTableData, /) -> None: ...
    def start(self, /) -> None: ...
    def stateNames(self, /, compress: bool = ...) -> typing.List[str]: ...
    def stop(self, /) -> None: ...
    @typing.overload
    def submitEvent(self, event: PySide6.QtScxml.QScxmlEvent, /) -> None: ...
    @typing.overload
    def submitEvent(self, eventName: str, /) -> None: ...
    @typing.overload
    def submitEvent(self, eventName: str, data: typing.Any, /) -> None: ...
    def tableData(self, /) -> PySide6.QtScxml.QScxmlTableData: ...


class QScxmlStaticScxmlServiceFactory(PySide6.QtScxml.QScxmlInvokableServiceFactory):

    def __init__(self, metaObject: PySide6.QtCore.QMetaObject, invokeInfo: PySide6.QtScxml.QScxmlExecutableContent.InvokeInfo, nameList: collections.abc.Sequence[int], parameters: collections.abc.Sequence[PySide6.QtScxml.QScxmlExecutableContent.ParameterInfo], /, parent: PySide6.QtCore.QObject | None = ...) -> None: ...

    def invoke(self, parentStateMachine: PySide6.QtScxml.QScxmlStateMachine, /) -> PySide6.QtScxml.QScxmlInvokableService: ...


class QScxmlTableData(Shiboken.Object):

    def __init__(self, /) -> None: ...

    def assignmentInfo(self, assignmentId: int, /) -> PySide6.QtScxml.QScxmlExecutableContent.AssignmentInfo: ...
    def dataNames(self, /) -> typing.Tuple[typing.List[int], int]: ...
    def evaluatorInfo(self, evaluatorId: int, /) -> PySide6.QtScxml.QScxmlExecutableContent.EvaluatorInfo: ...
    def foreachInfo(self, foreachId: int, /) -> PySide6.QtScxml.QScxmlExecutableContent.ForeachInfo: ...
    def initialSetup(self, /) -> int: ...
    def instructions(self, /) -> typing.List[int]: ...
    def name(self, /) -> str: ...
    def serviceFactory(self, id: int, /) -> PySide6.QtScxml.QScxmlInvokableServiceFactory: ...
    def stateMachineTable(self, /) -> typing.List[int]: ...
    def string(self, id: int, /) -> str: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtXml, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtXml`

import PySide6.QtXml
import PySide6.QtCore

import enum
import typing
import collections.abc
from shiboken6 import Shiboken


class QDomAttr(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, attr: PySide6.QtXml.QDomAttr, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def name(self, /) -> str: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def ownerElement(self, /) -> PySide6.QtXml.QDomElement: ...
    def setValue(self, value: str, /) -> None: ...
    def specified(self, /) -> bool: ...
    def value(self, /) -> str: ...


class QDomCDATASection(PySide6.QtXml.QDomText):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, cdataSection: PySide6.QtXml.QDomCDATASection, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...


class QDomCharacterData(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, characterData: PySide6.QtXml.QDomCharacterData, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def appendData(self, arg: str, /) -> None: ...
    def data(self, /) -> str: ...
    def deleteData(self, offset: int, count: int, /) -> None: ...
    def insertData(self, offset: int, arg: str, /) -> None: ...
    def length(self, /) -> int: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def replaceData(self, offset: int, count: int, arg: str, /) -> None: ...
    def setData(self, data: str, /) -> None: ...
    def substringData(self, offset: int, count: int, /) -> str: ...


class QDomComment(PySide6.QtXml.QDomCharacterData):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, comment: PySide6.QtXml.QDomComment, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...


class QDomDocument(PySide6.QtXml.QDomNode):

    class ParseOption(enum.Flag):

        Default                   = 0x0
        UseNamespaceProcessing    = 0x1
        PreserveSpacingOnlyNodes  = 0x2

    class ParseResult(Shiboken.Object):

        errorColumn               = ...  # type: int
        errorLine                 = ...  # type: int
        errorMessage              = ...  # type: str

        @typing.overload
        def __init__(self, /) -> None: ...
        @typing.overload
        def __init__(self, ParseResult: PySide6.QtXml.QDomDocument.ParseResult, /) -> None: ...

        def __copy__(self, /) -> typing.Self: ...


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, document: PySide6.QtXml.QDomDocument, /) -> None: ...
    @typing.overload
    def __init__(self, doctype: PySide6.QtXml.QDomDocumentType, /) -> None: ...
    @typing.overload
    def __init__(self, name: str, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def createAttribute(self, name: str, /) -> PySide6.QtXml.QDomAttr: ...
    def createAttributeNS(self, nsURI: str, qName: str, /) -> PySide6.QtXml.QDomAttr: ...
    def createCDATASection(self, data: str, /) -> PySide6.QtXml.QDomCDATASection: ...
    def createComment(self, data: str, /) -> PySide6.QtXml.QDomComment: ...
    def createDocumentFragment(self, /) -> PySide6.QtXml.QDomDocumentFragment: ...
    def createElement(self, tagName: str, /) -> PySide6.QtXml.QDomElement: ...
    def createElementNS(self, nsURI: str, qName: str, /) -> PySide6.QtXml.QDomElement: ...
    def createEntityReference(self, name: str, /) -> PySide6.QtXml.QDomEntityReference: ...
    def createProcessingInstruction(self, target: str, data: str, /) -> PySide6.QtXml.QDomProcessingInstruction: ...
    def createTextNode(self, data: str, /) -> PySide6.QtXml.QDomText: ...
    def doctype(self, /) -> PySide6.QtXml.QDomDocumentType: ...
    def documentElement(self, /) -> PySide6.QtXml.QDomElement: ...
    def elementById(self, elementId: str, /) -> PySide6.QtXml.QDomElement: ...
    def elementsByTagName(self, tagname: str, /) -> PySide6.QtXml.QDomNodeList: ...
    def elementsByTagNameNS(self, nsURI: str, localName: str, /) -> PySide6.QtXml.QDomNodeList: ...
    def implementation(self, /) -> PySide6.QtXml.QDomImplementation: ...
    def importNode(self, importedNode: PySide6.QtXml.QDomNode, deep: bool, /) -> PySide6.QtXml.QDomNode: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    @typing.overload
    def setContent(self, dev: PySide6.QtCore.QIODevice, /) -> typing.Tuple[bool, str, int, int]: ...
    @typing.overload
    def setContent(self, device: PySide6.QtCore.QIODevice, /, options: PySide6.QtXml.QDomDocument.ParseOption = ...) -> PySide6.QtXml.QDomDocument.ParseResult: ...
    @typing.overload
    def setContent(self, dev: PySide6.QtCore.QIODevice, namespaceProcessing: bool, /) -> typing.Tuple[bool, str, int, int]: ...
    @typing.overload
    def setContent(self, reader: PySide6.QtCore.QXmlStreamReader, /, options: PySide6.QtXml.QDomDocument.ParseOption = ...) -> PySide6.QtXml.QDomDocument.ParseResult: ...
    @typing.overload
    def setContent(self, reader: PySide6.QtCore.QXmlStreamReader, namespaceProcessing: bool, /) -> typing.Tuple[bool, str, int, int]: ...
    @typing.overload
    def setContent(self, text: str, /) -> typing.Tuple[bool, str, int, int]: ...
    @typing.overload
    def setContent(self, data: str, /, options: PySide6.QtXml.QDomDocument.ParseOption = ...) -> PySide6.QtXml.QDomDocument.ParseResult: ...
    @typing.overload
    def setContent(self, text: str, namespaceProcessing: bool, /) -> typing.Tuple[bool, str, int, int]: ...
    @typing.overload
    def setContent(self, text: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /) -> typing.Tuple[bool, str, int, int]: ...
    @typing.overload
    def setContent(self, data: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, /, options: PySide6.QtXml.QDomDocument.ParseOption = ...) -> PySide6.QtXml.QDomDocument.ParseResult: ...
    @typing.overload
    def setContent(self, text: PySide6.QtCore.QByteArray | bytes | bytearray | memoryview, namespaceProcessing: bool, /) -> typing.Tuple[bool, str, int, int]: ...
    def toByteArray(self, /, indent: int = ...) -> PySide6.QtCore.QByteArray: ...
    def toString(self, /, indent: int = ...) -> str: ...


class QDomDocumentFragment(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, documentFragment: PySide6.QtXml.QDomDocumentFragment, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...


class QDomDocumentType(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, documentType: PySide6.QtXml.QDomDocumentType, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def entities(self, /) -> PySide6.QtXml.QDomNamedNodeMap: ...
    def internalSubset(self, /) -> str: ...
    def name(self, /) -> str: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def notations(self, /) -> PySide6.QtXml.QDomNamedNodeMap: ...
    def publicId(self, /) -> str: ...
    def systemId(self, /) -> str: ...


class QDomElement(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, element: PySide6.QtXml.QDomElement, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def attribute(self, name: str, /, defValue: str = ...) -> str: ...
    def attributeNS(self, nsURI: str, localName: str, /, defValue: str = ...) -> str: ...
    def attributeNode(self, name: str, /) -> PySide6.QtXml.QDomAttr: ...
    def attributeNodeNS(self, nsURI: str, localName: str, /) -> PySide6.QtXml.QDomAttr: ...
    def attributes(self, /) -> PySide6.QtXml.QDomNamedNodeMap: ...
    def elementsByTagName(self, tagname: str, /) -> PySide6.QtXml.QDomNodeList: ...
    def elementsByTagNameNS(self, nsURI: str, localName: str, /) -> PySide6.QtXml.QDomNodeList: ...
    def hasAttribute(self, name: str, /) -> bool: ...
    def hasAttributeNS(self, nsURI: str, localName: str, /) -> bool: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def removeAttribute(self, name: str, /) -> None: ...
    def removeAttributeNS(self, nsURI: str, localName: str, /) -> None: ...
    def removeAttributeNode(self, oldAttr: PySide6.QtXml.QDomAttr, /) -> PySide6.QtXml.QDomAttr: ...
    @typing.overload
    def setAttribute(self, name: str, value: str, /) -> None: ...
    @typing.overload
    def setAttribute(self, name: str, value: int, /) -> None: ...
    @typing.overload
    def setAttribute(self, name: str, value: float, /) -> None: ...
    @typing.overload
    def setAttributeNS(self, nsURI: str, qName: str, value: str, /) -> None: ...
    @typing.overload
    def setAttributeNS(self, nsURI: str, qName: str, value: int, /) -> None: ...
    @typing.overload
    def setAttributeNS(self, nsURI: str, qName: str, value: float, /) -> None: ...
    def setAttributeNode(self, newAttr: PySide6.QtXml.QDomAttr, /) -> PySide6.QtXml.QDomAttr: ...
    def setAttributeNodeNS(self, newAttr: PySide6.QtXml.QDomAttr, /) -> PySide6.QtXml.QDomAttr: ...
    def setTagName(self, name: str, /) -> None: ...
    def tagName(self, /) -> str: ...
    def text(self, /) -> str: ...


class QDomEntity(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, entity: PySide6.QtXml.QDomEntity, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def notationName(self, /) -> str: ...
    def publicId(self, /) -> str: ...
    def systemId(self, /) -> str: ...


class QDomEntityReference(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, entityReference: PySide6.QtXml.QDomEntityReference, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...


class QDomImplementation(Shiboken.Object):

    class InvalidDataPolicy(enum.Enum):

        AcceptInvalidChars        = 0x0
        DropInvalidChars          = 0x1
        ReturnNullNode            = 0x2


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, implementation: PySide6.QtXml.QDomImplementation, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtXml.QDomImplementation, /) -> bool: ...
    def __ne__(self, other: PySide6.QtXml.QDomImplementation, /) -> bool: ...
    def createDocument(self, nsURI: str, qName: str, doctype: PySide6.QtXml.QDomDocumentType, /) -> PySide6.QtXml.QDomDocument: ...
    def createDocumentType(self, qName: str, publicId: str, systemId: str, /) -> PySide6.QtXml.QDomDocumentType: ...
    def hasFeature(self, feature: str, version: str, /) -> bool: ...
    @staticmethod
    def invalidDataPolicy() -> PySide6.QtXml.QDomImplementation.InvalidDataPolicy: ...
    def isNull(self, /) -> bool: ...
    @staticmethod
    def setInvalidDataPolicy(policy: PySide6.QtXml.QDomImplementation.InvalidDataPolicy, /) -> None: ...


class QDomNamedNodeMap(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, namedNodeMap: PySide6.QtXml.QDomNamedNodeMap, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtXml.QDomNamedNodeMap, /) -> bool: ...
    def __ne__(self, other: PySide6.QtXml.QDomNamedNodeMap, /) -> bool: ...
    def contains(self, name: str, /) -> bool: ...
    def count(self, /) -> int: ...
    def isEmpty(self, /) -> bool: ...
    def item(self, index: int, /) -> PySide6.QtXml.QDomNode: ...
    def length(self, /) -> int: ...
    def namedItem(self, name: str, /) -> PySide6.QtXml.QDomNode: ...
    def namedItemNS(self, nsURI: str, localName: str, /) -> PySide6.QtXml.QDomNode: ...
    def removeNamedItem(self, name: str, /) -> PySide6.QtXml.QDomNode: ...
    def removeNamedItemNS(self, nsURI: str, localName: str, /) -> PySide6.QtXml.QDomNode: ...
    def setNamedItem(self, newNode: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def setNamedItemNS(self, newNode: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def size(self, /) -> int: ...


class QDomNode(Shiboken.Object):

    class EncodingPolicy(enum.Enum):

        EncodingFromDocument      = 0x1
        EncodingFromTextStream    = 0x2

    class NodeType(enum.Enum):

        ElementNode               = 0x1
        AttributeNode             = 0x2
        TextNode                  = 0x3
        CDATASectionNode          = 0x4
        EntityReferenceNode       = 0x5
        EntityNode                = 0x6
        ProcessingInstructionNode = 0x7
        CommentNode               = 0x8
        DocumentNode              = 0x9
        DocumentTypeNode          = 0xa
        DocumentFragmentNode      = 0xb
        NotationNode              = 0xc
        BaseNode                  = 0x15
        CharacterDataNode         = 0x16


    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, node: PySide6.QtXml.QDomNode, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, other: PySide6.QtXml.QDomNode, /) -> bool: ...
    def __lshift__(self, stream: PySide6.QtCore.QTextStream, /) -> PySide6.QtCore.QTextStream: ...
    def __ne__(self, other: PySide6.QtXml.QDomNode, /) -> bool: ...
    def appendChild(self, newChild: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def attributes(self, /) -> PySide6.QtXml.QDomNamedNodeMap: ...
    def childNodes(self, /) -> PySide6.QtXml.QDomNodeList: ...
    def clear(self, /) -> None: ...
    def cloneNode(self, /, deep: bool = ...) -> PySide6.QtXml.QDomNode: ...
    def columnNumber(self, /) -> int: ...
    def firstChild(self, /) -> PySide6.QtXml.QDomNode: ...
    def firstChildElement(self, /, tagName: str = ..., namespaceURI: str = ...) -> PySide6.QtXml.QDomElement: ...
    def hasAttributes(self, /) -> bool: ...
    def hasChildNodes(self, /) -> bool: ...
    def insertAfter(self, newChild: PySide6.QtXml.QDomNode, refChild: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def insertBefore(self, newChild: PySide6.QtXml.QDomNode, refChild: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def isAttr(self, /) -> bool: ...
    def isCDATASection(self, /) -> bool: ...
    def isCharacterData(self, /) -> bool: ...
    def isComment(self, /) -> bool: ...
    def isDocument(self, /) -> bool: ...
    def isDocumentFragment(self, /) -> bool: ...
    def isDocumentType(self, /) -> bool: ...
    def isElement(self, /) -> bool: ...
    def isEntity(self, /) -> bool: ...
    def isEntityReference(self, /) -> bool: ...
    def isNotation(self, /) -> bool: ...
    def isNull(self, /) -> bool: ...
    def isProcessingInstruction(self, /) -> bool: ...
    def isSupported(self, feature: str, version: str, /) -> bool: ...
    def isText(self, /) -> bool: ...
    def lastChild(self, /) -> PySide6.QtXml.QDomNode: ...
    def lastChildElement(self, /, tagName: str = ..., namespaceURI: str = ...) -> PySide6.QtXml.QDomElement: ...
    def lineNumber(self, /) -> int: ...
    def localName(self, /) -> str: ...
    def namedItem(self, name: str, /) -> PySide6.QtXml.QDomNode: ...
    def namespaceURI(self, /) -> str: ...
    def nextSibling(self, /) -> PySide6.QtXml.QDomNode: ...
    def nextSiblingElement(self, /, taName: str = ..., namespaceURI: str = ...) -> PySide6.QtXml.QDomElement: ...
    def nodeName(self, /) -> str: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def nodeValue(self, /) -> str: ...
    def normalize(self, /) -> None: ...
    def ownerDocument(self, /) -> PySide6.QtXml.QDomDocument: ...
    def parentNode(self, /) -> PySide6.QtXml.QDomNode: ...
    def prefix(self, /) -> str: ...
    def previousSibling(self, /) -> PySide6.QtXml.QDomNode: ...
    def previousSiblingElement(self, /, tagName: str = ..., namespaceURI: str = ...) -> PySide6.QtXml.QDomElement: ...
    def removeChild(self, oldChild: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def replaceChild(self, newChild: PySide6.QtXml.QDomNode, oldChild: PySide6.QtXml.QDomNode, /) -> PySide6.QtXml.QDomNode: ...
    def save(self, arg__1: PySide6.QtCore.QTextStream, arg__2: int, /, arg__3: PySide6.QtXml.QDomNode.EncodingPolicy = ...) -> None: ...
    def setNodeValue(self, value: str, /) -> None: ...
    def setPrefix(self, pre: str, /) -> None: ...
    def toAttr(self, /) -> PySide6.QtXml.QDomAttr: ...
    def toCDATASection(self, /) -> PySide6.QtXml.QDomCDATASection: ...
    def toCharacterData(self, /) -> PySide6.QtXml.QDomCharacterData: ...
    def toComment(self, /) -> PySide6.QtXml.QDomComment: ...
    def toDocument(self, /) -> PySide6.QtXml.QDomDocument: ...
    def toDocumentFragment(self, /) -> PySide6.QtXml.QDomDocumentFragment: ...
    def toDocumentType(self, /) -> PySide6.QtXml.QDomDocumentType: ...
    def toElement(self, /) -> PySide6.QtXml.QDomElement: ...
    def toEntity(self, /) -> PySide6.QtXml.QDomEntity: ...
    def toEntityReference(self, /) -> PySide6.QtXml.QDomEntityReference: ...
    def toNotation(self, /) -> PySide6.QtXml.QDomNotation: ...
    def toProcessingInstruction(self, /) -> PySide6.QtXml.QDomProcessingInstruction: ...
    def toText(self, /) -> PySide6.QtXml.QDomText: ...


class QDomNodeList(Shiboken.Object):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, nodeList: PySide6.QtXml.QDomNodeList, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def __eq__(self, rhs: PySide6.QtXml.QDomNodeList, /) -> bool: ...
    def __ne__(self, rhs: PySide6.QtXml.QDomNodeList, /) -> bool: ...
    def at(self, index: int, /) -> PySide6.QtXml.QDomNode: ...
    def count(self, /) -> int: ...
    def isEmpty(self, /) -> bool: ...
    def item(self, index: int, /) -> PySide6.QtXml.QDomNode: ...
    def length(self, /) -> int: ...
    def size(self, /) -> int: ...


class QDomNotation(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, notation: PySide6.QtXml.QDomNotation, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def publicId(self, /) -> str: ...
    def systemId(self, /) -> str: ...


class QDomProcessingInstruction(PySide6.QtXml.QDomNode):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, processingInstruction: PySide6.QtXml.QDomProcessingInstruction, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def data(self, /) -> str: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def setData(self, data: str, /) -> None: ...
    def target(self, /) -> str: ...


class QDomText(PySide6.QtXml.QDomCharacterData):

    @typing.overload
    def __init__(self, /) -> None: ...
    @typing.overload
    def __init__(self, text: PySide6.QtXml.QDomText, /) -> None: ...

    def __copy__(self, /) -> typing.Self: ...
    def nodeType(self, /) -> PySide6.QtXml.QDomNode.NodeType: ...
    def splitText(self, offset: int, /) -> PySide6.QtXml.QDomText: ...


class QIntList: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof



# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
"""
This file contains the exact signatures for all functions in module
PySide6.QtOpenGLWidgets, except for defaults which are replaced by "...".
"""

# mypy: disable-error-code="override, overload-overlap"
# Module `PySide6.QtOpenGLWidgets`

import PySide6.QtOpenGLWidgets
import PySide6.QtCore
import PySide6.QtGui
import PySide6.QtWidgets

import enum
import typing
import collections.abc
from PySide6.QtCore import Signal


class QIntList: ...


class QOpenGLWidget(PySide6.QtWidgets.QWidget):

    aboutToCompose           : typing.ClassVar[Signal] = ... # aboutToCompose()
    aboutToResize            : typing.ClassVar[Signal] = ... # aboutToResize()
    frameSwapped             : typing.ClassVar[Signal] = ... # frameSwapped()
    resized                  : typing.ClassVar[Signal] = ... # resized()

    class TargetBuffer(enum.Enum):

        LeftBuffer                = 0x0
        RightBuffer               = 0x1

    class UpdateBehavior(enum.Enum):

        NoPartialUpdate           = 0x0
        PartialUpdate             = 0x1


    def __init__(self, /, parent: PySide6.QtWidgets.QWidget | None = ..., f: PySide6.QtCore.Qt.WindowType = ...) -> None: ...

    def context(self, /) -> PySide6.QtGui.QOpenGLContext: ...
    def currentTargetBuffer(self, /) -> PySide6.QtOpenGLWidgets.QOpenGLWidget.TargetBuffer: ...
    @typing.overload
    def defaultFramebufferObject(self, /) -> int: ...
    @typing.overload
    def defaultFramebufferObject(self, targetBuffer: PySide6.QtOpenGLWidgets.QOpenGLWidget.TargetBuffer, /) -> int: ...
    def doneCurrent(self, /) -> None: ...
    def event(self, e: PySide6.QtCore.QEvent, /) -> bool: ...
    def format(self, /) -> PySide6.QtGui.QSurfaceFormat: ...
    @typing.overload
    def grabFramebuffer(self, /) -> PySide6.QtGui.QImage: ...
    @typing.overload
    def grabFramebuffer(self, targetBuffer: PySide6.QtOpenGLWidgets.QOpenGLWidget.TargetBuffer, /) -> PySide6.QtGui.QImage: ...
    def initializeGL(self, /) -> None: ...
    def isValid(self, /) -> bool: ...
    @typing.overload
    def makeCurrent(self, /) -> None: ...
    @typing.overload
    def makeCurrent(self, targetBuffer: PySide6.QtOpenGLWidgets.QOpenGLWidget.TargetBuffer, /) -> None: ...
    def metric(self, metric: PySide6.QtGui.QPaintDevice.PaintDeviceMetric, /) -> int: ...
    def paintEngine(self, /) -> PySide6.QtGui.QPaintEngine: ...
    def paintEvent(self, e: PySide6.QtGui.QPaintEvent, /) -> None: ...
    def paintGL(self, /) -> None: ...
    def redirected(self, p: PySide6.QtCore.QPoint, /) -> PySide6.QtGui.QPaintDevice: ...
    def resizeEvent(self, e: PySide6.QtGui.QResizeEvent, /) -> None: ...
    def resizeGL(self, w: int, h: int, /) -> None: ...
    def setFormat(self, format: PySide6.QtGui.QSurfaceFormat | PySide6.QtGui.QSurfaceFormat.FormatOption, /) -> None: ...
    def setTextureFormat(self, texFormat: int, /) -> None: ...
    def setUpdateBehavior(self, updateBehavior: PySide6.QtOpenGLWidgets.QOpenGLWidget.UpdateBehavior, /) -> None: ...
    def textureFormat(self, /) -> int: ...
    def updateBehavior(self, /) -> PySide6.QtOpenGLWidgets.QOpenGLWidget.UpdateBehavior: ...


def __dir__(self, /) -> collections.abc.Iterable[str]: ...


# eof
